@@ -14,16 +14,16 @@ logger = logging.getLogger(__name__)
 
 def check(odb: "ObjectDB", obj: "HashFile", **kwargs):
     if isinstance(obj, Tree):
-        for _, _, oid in obj:
-            odb.check(oid, **kwargs)
+        for _, _, hash_info in obj:
+            odb.check(hash_info.value, **kwargs)
 
-    odb.check(obj.hash_info, **kwargs)
+    odb.check(obj.oid, **kwargs)
 
 
 def load(odb: "ObjectDB", hash_info: "HashInfo") -> "HashFile":
     if hash_info.isdir:
         return Tree.load(odb, hash_info)
-    return odb.get(hash_info)
+    return odb.get(hash_info.value)
 
 
 def iterobjs(
