@@ -8,16 +8,16 @@ from typing import TYPE_CHECKING, Dict, Optional, Tuple
 
 from dvc_objects._tqdm import Tqdm
 from dvc_objects.hashfile.hash import hash_file
-from dvc_objects.hashfile.hash_info import HashInfo
 from dvc_objects.hashfile.meta import Meta
 from dvc_objects.hashfile.obj import HashFile
 
-from .db.reference import ReferenceObjectDB
+from .db.reference import ReferenceHashFileDB
 
 if TYPE_CHECKING:
     from dvc_objects._ignore import Ignore
-    from dvc_objects.db import ObjectDB
     from dvc_objects.fs.base import AnyFSPath, FileSystem
+    from dvc_objects.hashfile.db import HashFileDB
+    from dvc_objects.hashfile.hash_info import HashInfo
 
     from .objects.tree import Tree
 
@@ -39,48 +39,49 @@ logger = logging.getLogger(__name__)
 _STAGING_MEMFS_PATH = "dvc-staging"
 
 
-def _upload_file(from_fs_path, fs, odb, upload_odb, callback=None):
+def _upload_file(from_path, fs, odb, upload_odb, callback=None):
     from dvc_objects.fs.callbacks import Callback
     from dvc_objects.fs.utils import tmp_fname
     from dvc_objects.hashfile.hash import HashStreamFile
 
-    fs_path = upload_odb.fs.path
-    tmp_info = fs_path.join(upload_odb.fs_path, tmp_fname())
-    with fs.open(from_fs_path, mode="rb") as stream:
+    path = upload_odb.fs.path
+    tmp_info = path.join(upload_odb.path, tmp_fname())
+    with fs.open(from_path, mode="rb") as stream:
         stream = HashStreamFile(stream)
-        size = fs.size(from_fs_path)
+        size = fs.size(from_path)
         with Callback.as_tqdm_callback(
             callback,
-            desc=fs_path.name(from_fs_path),
+            desc=path.name(from_path),
             bytes=True,
             size=size,
         ) as cb:
             upload_odb.fs.put_file(stream, tmp_info, size=size, callback=cb)
 
-    hash_info = HashInfo(stream.hash_name, stream.hash_value)
-    odb.add(tmp_info, upload_odb.fs, hash_info)
+    oid = stream.hash_value
+    odb.add(tmp_info, upload_odb.fs, oid)
     meta = Meta(size=size)
-    return from_fs_path, meta, odb.get(hash_info)
+    return from_path, meta, odb.get(oid)
 
 
-def _stage_file(fs_path, fs, name, odb=None, upload_odb=None, dry_run=False):
+def _stage_file(path, fs, name, odb=None, upload_odb=None, dry_run=False):
     state = odb.state if odb else None
-    meta, hash_info = hash_file(fs_path, fs, name, state=state)
+    meta, hash_info = hash_file(path, fs, name, state=state)
     if upload_odb and not dry_run:
         assert odb and name == "md5"
-        return _upload_file(fs_path, fs, odb, upload_odb)
+        return _upload_file(path, fs, odb, upload_odb)
 
+    oid = hash_info.value
     if dry_run:
-        obj = HashFile(fs_path, fs, hash_info)
+        obj = HashFile(path, fs, hash_info)
     else:
-        odb.add(fs_path, fs, hash_info, hardlink=False)
-        obj = odb.get(hash_info)
+        odb.add(path, fs, oid, hardlink=False)
+        obj = odb.get(oid)
 
-    return fs_path, meta, obj
+    return path, meta, obj
 
 
 def _build_objects(
-    fs_path,
+    path,
     fs,
     name,
     ignore: "Ignore" = None,
@@ -89,9 +90,9 @@ def _build_objects(
     **kwargs,
 ):
     if ignore:
-        walk_iterator = ignore.find(fs, fs_path)
+        walk_iterator = ignore.find(fs, path)
     else:
-        walk_iterator = fs.find(fs_path)
+        walk_iterator = fs.find(path)
     with Tqdm(
         unit="md5",
         desc="Computing file/dir hashes (only done once)",
@@ -111,11 +112,11 @@ def _build_objects(
             yield from executor.map(worker, walk_iterator)
 
 
-def _iter_objects(fs_path, fs, name, **kwargs):
-    yield from _build_objects(fs_path, fs, name, **kwargs)
+def _iter_objects(path, fs, name, **kwargs):
+    yield from _build_objects(path, fs, name, **kwargs)
 
 
-def _build_tree(fs_path, fs, name, **kwargs):
+def _build_tree(path, fs, name, **kwargs):
     from .objects.tree import Tree
 
     tree_meta = Meta(size=0, nfiles=0)
@@ -123,11 +124,11 @@ def _build_tree(fs_path, fs, name, **kwargs):
     assert tree_meta.size is not None
     assert tree_meta.nfiles is not None
 
-    tree = Tree(None, None, None)
-    for file_fs_path, meta, obj in _iter_objects(fs_path, fs, name, **kwargs):
-        if fs.path.name(file_fs_path) == DefaultIgnoreFile:
+    tree = Tree()
+    for file_path, meta, obj in _iter_objects(path, fs, name, **kwargs):
+        if fs.path.name(file_path) == DefaultIgnoreFile:
             raise IgnoreInCollectedDirError(
-                DefaultIgnoreFile, fs.path.parent(file_fs_path)
+                DefaultIgnoreFile, fs.path.parent(file_path)
             )
 
         # NOTE: this is lossy transformation:
@@ -139,7 +140,7 @@ def _build_tree(fs_path, fs, name, **kwargs):
         # Yes, this is a BUG, as long as we permit "/" in
         # filenames on Windows and "\" on Unix
 
-        key = fs.path.relparts(file_fs_path, fs_path)
+        key = fs.path.relparts(file_path, path)
         assert key
         tree.add(key, meta, obj.hash_info)
 
@@ -149,34 +150,35 @@ def _build_tree(fs_path, fs, name, **kwargs):
     return tree_meta, tree
 
 
-def _stage_tree(fs_path, fs, fs_info, name, odb=None, **kwargs):
+def _stage_tree(path, fs, fs_info, name, odb=None, **kwargs):
+    from dvc_objects.hashfile.hash_info import HashInfo
+
     from .objects.tree import Tree
 
     value = fs_info.get(name)
     if odb and value:
-        hash_info = HashInfo(name, value)
         try:
-            tree = Tree.load(odb, hash_info)
+            tree = Tree.load(odb, HashInfo(name, value))
             return Meta(nfiles=len(tree)), tree
         except FileNotFoundError:
             pass
 
-    meta, tree = _build_tree(fs_path, fs, name, odb=odb, **kwargs)
+    meta, tree = _build_tree(path, fs, name, odb=odb, **kwargs)
     state = odb.state if odb and odb.state else None
     hash_info = None
     if state:
         _, hash_info = state.get(  # pylint: disable=assignment-from-none
-            fs_path, fs
+            path, fs
         )
     tree.digest(hash_info=hash_info)
-    odb.add(tree.fs_path, tree.fs, tree.hash_info, hardlink=False)
-    raw = odb.get(tree.hash_info)
+    odb.add(tree.path, tree.fs, tree.oid, hardlink=False)
+    raw = odb.get(tree.oid)
     # cleanup unneeded memfs tmpfile and return tree based on the
     # ODB fs/path
     if odb.fs != tree.fs:
-        tree.fs.remove(tree.fs_path)
+        tree.fs.remove(tree.path)
     tree.fs = raw.fs
-    tree.fs_path = raw.fs_path
+    tree.path = raw.path
     return meta, tree
 
 
@@ -184,27 +186,25 @@ _url_cache: Dict[str, str] = {}
 
 
 def _make_staging_url(
-    fs: "FileSystem", odb: "ObjectDB", fs_path: Optional[str]
+    fs: "FileSystem", odb: "HashFileDB", path: Optional[str]
 ):
     from dvc_objects.fs import Schemes
 
     url = f"{Schemes.MEMORY}://{_STAGING_MEMFS_PATH}"
 
-    if fs_path is not None:
+    if path is not None:
         if odb.fs.protocol == Schemes.LOCAL:
-            fs_path = os.path.abspath(fs_path)
+            path = os.path.abspath(path)
 
-        if fs_path not in _url_cache:
-            _url_cache[fs_path] = hashlib.sha256(
-                fs_path.encode("utf-8")
-            ).hexdigest()
+        if path not in _url_cache:
+            _url_cache[path] = hashlib.sha256(path.encode("utf-8")).hexdigest()
 
-        url = fs.path.join(url, _url_cache[fs_path])
+        url = fs.path.join(url, _url_cache[path])
 
     return url
 
 
-def _get_staging(odb: "ObjectDB") -> "ReferenceObjectDB":
+def _get_staging(odb: "HashFileDB") -> "ReferenceHashFileDB":
     """Return an ODB that can be used for staging objects.
 
     Staging will be a reference ODB stored in the the global memfs.
@@ -213,50 +213,53 @@ def _get_staging(odb: "ObjectDB") -> "ReferenceObjectDB":
     from dvc_objects.fs import MemoryFileSystem
 
     fs = MemoryFileSystem()
-    fs_path = _make_staging_url(fs, odb, odb.fs_path)
+    path = _make_staging_url(fs, odb, odb.path)
     state = odb.state
-    return ReferenceObjectDB(fs, fs_path, state=state)
+    return ReferenceHashFileDB(fs, path, state=state)
 
 
-def _load_raw_dir_obj(odb: "ObjectDB", hash_info: "HashInfo") -> "Tree":
+def _load_raw_dir_obj(odb: "HashFileDB", hash_info: "HashInfo") -> "Tree":
     from dvc_objects.errors import ObjectFormatError
 
     from .objects.tree import Tree
 
     try:
-        tree = Tree.load(odb, hash_info.as_raw())
-        tree.check(odb)
+        raw = hash_info.as_raw()
+        oid = raw.value
+        tree = Tree.load(odb, raw)
+        odb.check(oid)
         tree.hash_info = hash_info
+        tree.oid = hash_info.value
     except ObjectFormatError as exc:
         raise FileNotFoundError(
             errno.ENOENT,
             "No such object",
-            odb.hash_to_path(hash_info.as_raw().value),
+            odb.oid_to_path(hash_info.as_raw().value),
         ) from exc
 
     return tree
 
 
 def _load_from_state(
-    odb: "ObjectDB",
-    staging: "ReferenceObjectDB",
-    fs_path: "AnyFSPath",
+    odb: "HashFileDB",
+    staging: "ReferenceHashFileDB",
+    path: "AnyFSPath",
     fs: "FileSystem",
     name: str,
     dry_run: bool,
-) -> Tuple["ObjectDB", "Meta", "HashFile"]:
+) -> Tuple["HashFileDB", "Meta", "HashFile"]:
     from dvc_objects.errors import ObjectFormatError
 
     from . import check, load
     from .objects.tree import Tree
 
     state = odb.state
-    meta, hash_info = state.get(fs_path, fs)
+    meta, hash_info = state.get(path, fs)
     if not hash_info:
         raise FileNotFoundError
 
     for odb_ in (odb, staging):
-        if not odb_.exists(hash_info):
+        if not odb_.exists(hash_info.value):
             continue
 
         try:
@@ -280,25 +283,25 @@ def _load_from_state(
 
     if not dry_run:
         assert tree.fs
-        for key, _, oid in tree:
+        for key, _, hi in tree:
             staging.add(
-                fs.path.join(fs_path, *key),
+                fs.path.join(path, *key),
                 fs,
-                oid,
+                hi.value,
                 hardlink=False,
                 verify=False,
             )
 
         staging.add(
-            tree.fs_path,
+            tree.path,
             tree.fs,
-            hash_info,
+            hash_info.value,
             hardlink=False,
         )
 
-        raw = staging.get(hash_info)
+        raw = staging.get(hash_info.value)
         tree.fs = raw.fs
-        tree.fs_path = raw.fs_path
+        tree.path = raw.path
 
     logger.debug("loaded tree '%s' from raw dir obj", tree)
     return staging, meta, tree
@@ -311,10 +314,10 @@ def _stage_external_tree_info(odb, tree, name):
     # that would be universal for all clouds.
     assert odb and name != "md5"
 
-    odb.add(tree.fs_path, tree.fs, tree.hash_info)
+    odb.add(tree.path, tree.fs, tree.hash_info)
     raw = odb.get(tree.hash_info)
-    _, hash_info = hash_file(raw.fs_path, raw.fs, name, state=odb.state)
-    tree.fs_path = raw.fs_path
+    _, hash_info = hash_file(raw.path, raw.fs, name, state=odb.state)
+    tree.path = raw.path
     tree.fs = raw.fs
     tree.hash_info.name = hash_info.name
     tree.hash_info.value = hash_info.value
@@ -324,14 +327,14 @@ def _stage_external_tree_info(odb, tree, name):
 
 
 def stage(
-    odb: "ObjectDB",
-    fs_path: "AnyFSPath",
+    odb: "HashFileDB",
+    path: "AnyFSPath",
     fs: "FileSystem",
     name: str,
     upload: bool = False,
     dry_run: bool = False,
     **kwargs,
-) -> Tuple["ObjectDB", "Meta", "HashFile"]:
+) -> Tuple["HashFileDB", "Meta", "HashFile"]:
     """Stage (prepare) objects from the given path for addition to an ODB.
 
     Returns at tuple of (staging_odb, object) where addition to the ODB can
@@ -345,20 +348,20 @@ def stage(
     ODB filesystem, and staged objects will reference the uploaded path rather
     than the original source path.
     """
-    assert fs_path
-    # assert protocol(fs_path) == fs.protocol
+    assert path
+    # assert protocol(path) == fs.protocol
 
-    details = fs.info(fs_path)
+    details = fs.info(path)
     staging = _get_staging(odb)
     if odb:
         try:
-            return _load_from_state(odb, staging, fs_path, fs, name, dry_run)
+            return _load_from_state(odb, staging, path, fs, name, dry_run)
         except FileNotFoundError:
             pass
 
     if details["type"] == "directory":
         meta, obj = _stage_tree(
-            fs_path,
+            path,
             fs,
             details,
             name,
@@ -375,10 +378,10 @@ def stage(
         # the local odb (e.g. for a status call), we save it as a raw object.
         # Loading this instead of building the tree can speed up `dvc status`
         # for modified directories, see #7390
-        odb.add(obj.fs_path, obj.fs, obj.hash_info.as_raw())
+        odb.add(obj.path, obj.fs, obj.hash_info.as_raw().value)
     else:
         _, meta, obj = _stage_file(
-            fs_path,
+            path,
             fs,
             name,
             odb=staging,
@@ -387,6 +390,6 @@ def stage(
         )
 
     if odb and odb.state and obj.hash_info:
-        odb.state.save(fs_path, fs, obj.hash_info)
+        odb.state.save(path, fs, obj.hash_info)
 
     return staging, meta, obj
